// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: BadPixPSFCorrector
// Author: Hassan Siddiqui
//
// Description: 
//
// Point source implementation of an Encircled Energy Corrector class
//
// Modifications: See ChangeLog
// 
// $Id: BadPixPSFCorrector.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef BadPixPSFCorrector_H
#define BadPixPSFCorrector_H

/* General */

/* SAS-specific */

/* Local */
#include "IterEeCorrector.h"
#include "PixelIterator.h"
#include "PsfModel.h"
#include "DetmapFilter.h"
#include "MissingPixCorrector.h"

class BadPixPSFCorrector : public MissingPixCorrector
{
public:

  /* Constructor */
  BadPixPSFCorrector(const string & table, unsigned eefactor, 
                      PsfModel * psf, unsigned int ccdid); 
                                  

  /* Destructor */
  ~BadPixPSFCorrector();

  /* Method for filtering the map */
  void filterMap();

  int totalPixels() const;

private:

  DetmapFilter * _detmapfilter;
  PixelIterator * _pxitr;
  PixelIterator * _ctpxitr;
  PsfModel * _psf;
  const string _table;
  unsigned int _ccdid;

  double eeFraction( double energy ) const;

};

#endif
