// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// Module: CalMOSCoreData
// Author: Hassan Siddiqui
//
// Description: Cal MOS Instrument-specific data/methods for arf generation.
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: CalMOSCoreData.cc,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

/* General */
#include <iostream>
#include <iomanip>

/* SAS-specific classes */
#include "Xmm.h"
#include "common.h"
#include "OalServer.h"
#include "CalServer.h"
#include "Tracer.h"

/* Local classes */
#include "CalMOSCoreData.h"
#include "SimpleIterator.h"
#include "NonUnifBinnedAxis.h"
#include "NullPileupCorrector.h"

/* Constructors */

CalMOSCoreData::CalMOSCoreData( Xmm::Instrument instrumentID,
				const string & datamode,
				const string & dateobs,
				const PosWCS * const poswcs,
				const string & filter,
				double psfenergy) :
  CalCoreData(psfenergy, datamode, dateobs, poswcs)
{
  errstr << "Creating CalMOSCoreData object .. "
         << filter
	 << Sas::message(Msg::App, Msg::Verbose);

  /* Set up CAL server */
  //calServer.setInstrument(instrumentID);
  calServer.state()->ccd()->set(EMOScam::CCD_1);
  calServer.state()->node()->set(EMOScam::PRIMARY_NODE);

  //calServer.state()->filter()->set(Xmm::toFilter(filter)); 

  /* Switch off randomization */
  //calServer.state()->randomize()->set(false);

  /* Initialise remaining members */
  init(instrumentID);
};

/*  Destructors  */
CalMOSCoreData::~CalMOSCoreData()
{
  PROC;
  ENDPROC;
};

unsigned CalMOSCoreData::ccdFirst() const 
{ PROC; RETURN EMOScam::CCD_FIRST; }

unsigned CalMOSCoreData::ccdLast()  const 
{ PROC; RETURN EMOScam::CCD_LAST;  } 


/** Iterator methods. */

GeneralIterator<int> * CalMOSCoreData::xpixelIterator() const
{
  PROC;
  RETURN ( new SimpleIterator<int>( _emosCam.minX(), 
				    _emosCam.maxX()) );
}

GeneralIterator<int> * CalMOSCoreData::ypixelIterator() const
{
  PROC;
  RETURN ( new SimpleIterator<int>( _emosCam.minY(), 
				    _emosCam.maxY()) );
}
