// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// This  skeleton file was automatically created by 
//            pkgmaker 0.1
//            Thursday, December 11 1997
// 
// Module: DetTableIterator
// Author: Richard Saxton
//
// Description: 
//
// Class representation of an iterator that handles DAL-based detectormaps.
// It reads the detector pixel values from two columns in the input file
//
// Modifications: See ChangeLog
// 
// General classes
#include <iostream>
#include<cassert>
#include <limits>

// SAS-specific classes
#include "Dal.h"
#include "SscWcsConvertor.h"

// General utility functions
#include "errstr.h"
#include "Tracer.h"

// Local classes
#include "DetTableIterator.h"

/* Constructors */
DetTableIterator::DetTableIterator(const string & tablename, 
                                   const string & xcolname, const string & ycolname,
                                   const string & detxcolname, const string & detycolname,
                                   const string & valuecolname) :
TablePixelIterator(tablename, xcolname, ycolname, valuecolname)
{
 // Set up of base class TablePixelIterator done in constructor
 
 // Read in detector pixel values from columns in the table
  
  Column * detxColumn     = _table->column(detxcolname);
  Column * detyColumn     = _table->column(detycolname);

  _detxColData     = detxColumn->data();
  _detyColData     = detyColumn->data();

  _detxData        = _detxColData->int16Data();
  _detyData        = _detyColData->int16Data();
}

/* Destructor */
DetTableIterator::~DetTableIterator()
{
  PROC;
  
  delete _detxColData; _detxColData=0;
  delete _detyColData; _detyColData=0;
  // Allow parent to close down the rest 
  ENDPROC;
}

/* Overridden methods */
PixelElement DetTableIterator::currentItem()
{
  PROC;

  assert(_firstcalled);

  PixelElement result (_xData[_index],
		       _yData[_index],
		       _detxData[_index],
		       _detyData[_index],
		       _wcsconv->xWidth(),
		       _wcsconv->yWidth(),
		       _valueData[_index]) ;

  RETURN result;
}

CoordPair DetTableIterator::physXYmin() const
{
  PROC;

    short xmin=std::numeric_limits<short>::max();
    short ymin=xmin; 

   // Iterate through the det coord arrays and find the max and min value
    for (unsigned i  = 0; i < size(); ++i) {
        xmin=min(xmin,_detxData[i]); 
        ymin=min(ymin,_detyData[i]); 
    }

    RETURN CoordPair(xmin,ymin);
}
CoordPair DetTableIterator::physXYmax() const
{
  PROC;

    short xmax=std::numeric_limits<short>::min();
    short ymax=xmax; 

   // Iterate through the det coord arrays and find the max and min value
    for (unsigned i  = 0; i < size(); ++i) {
        xmax=max(xmax,_detxData[i]); 
        ymax=max(ymax,_detyData[i]); 
    }

    RETURN CoordPair(double(xmax),double(ymax));
}
