// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: NullBadPixelCorrector
// Author: Richard Saxton
//
// Description: 
//
// A class to return a null result for bad pixels
//
// Modifications: See ChangeLog
// 
// $Id: NullBadPixelCorrector.cc,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

/* General */

/* SAS-specific */
#include "Tracer.h"

/* Local */
#include "NumericalRange.h"
#include "NullBadPixelCorrector.h"
#include "PixelIterator.h"
#include "BpCorrector.h"

/* Constructor */
NullBadPixelCorrector::NullBadPixelCorrector()
{
  PROC;
  ENDPROC;
}

/* Destructor */
NullBadPixelCorrector::~NullBadPixelCorrector()
{
  PROC;
  ENDPROC;
}

vector<double>
NullBadPixelCorrector::TotalFactor(const vector<double> & energyVector) const
{
  PROC;

   vector<double> corrFactor;

    for (unsigned int i = 0; i < energyVector.size(); ++i) {
       corrFactor.push_back(0.0);
    }

  RETURN corrFactor;
}
  
int NullBadPixelCorrector::totalPixels() const
{
  PROC;

  RETURN 0;
}
