// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: OffCCDPSFCorrector
// Author: Richard Saxton
//
// Description:
//
// Class to return pixels within the source box which are in the chip
// gaps. These may be modified by the PSF function.
//
// Modifications: See ChangeLog
//
// $Id: OffCCDPSFCorrector.h,v 1.4 2009/09/03 13:19:51 aibarra Exp $

#ifndef OffCCDPSFCorrector_H
#define OffCCDPSFCorrector_H

/* General */

/* SAS-specific */

/* Local */
#include "IterEeCorrector.h"
#include "PixelIterator.h"
#include "PsfModel.h"
#include "MissingPixCorrector.h"

class OffCCDPSFCorrector : public MissingPixCorrector
{
public:

  /* Constructor */
  OffCCDPSFCorrector(unsigned eefactor, PsfModel * psf);

  /* Destructor */
  ~OffCCDPSFCorrector();

  /* Map filter */
  /* AI gcc4 porting
   * error: extra qualification ‘OffCCDPSFCorrector::’ on member ‘filterMap’
   * => OffCCDPSFCorrector:: removed
   */
  void filterMap();

  int totalPixels() const;

private:

  PixelIterator * _pxitr;
//  PixelIterator * _ocpxitr;
  PsfModel * _psf;

  double eeFraction( double energy ) const;

};

#endif
