// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// Module: PosWCS
//
// Author: Hassan Siddiqui
//
// Description:
//
// Reads in X/Y WCS from a given dataset.
//
// If the info in invalid/not present,
// the valid() method will return false.
//
// Modifications: See ChangeLog
//
// $Id: PosWCS.h,v 1.2 2009/09/03 13:19:51 aibarra Exp $

#ifndef PosWCS_H
#define PosWCS_H

/* SAS-specific */
#include "Dal.h"

/* Local classes */
#include "WCSConvertor.h"


class PosWCS
{
public:

  /* Read state from dataset */
  PosWCS( const DataSet * const set,
	  double default_ra,
	  double default_dec,
          double refpa,
          bool useodf );

  /* Destructor */
 ~ PosWCS();

  /* Returns a pointer to WCS object */
 /* AI gcc4 porting
  *   error: type qualifiers ignored on function return type
  *   => const removed
  */
 const WCSConvertor *  wcs() const;

  /* Returns the default dec,ra,pa */
  /* AI gcc4 porting
   * error: extra qualification ‘PosWCS::’ on member ‘xxx’
   */
   double refra() const;
   double refdec() const;
   double pa() const;

  /* Returns whether to use the ODF for attitude reconstruction */
   bool useODF() const;
  /* AI gcc4 porting
   * end
   */
private:

  bool _valid;

  double _refra;
  double _refdec;
  double _refpa;

  bool _useodf;

  const WCSConvertor * _wcs;
};

#endif
