// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// Module: RectanglePsfModel
// Author: Richard Saxton
//
// Description: 
//
// A simple model for the PSF.
// Used for prototyping; will be eventually replaced by relevant CAL fn.
//
// Modifications: See ChangeLog
// 
// $Id: RectanglePsfModel.h,v 1.1.1.1 2004/02/09 14:54:12 eojero Exp $

#ifndef RectanglePsfModel_H
#define RectanglePsfModel_H

/* SAS-specific */
#include "CalCommon.h"
#include "CalServer.h"
#include "EncircledEnergyDataServer.h"

/* Local */
#include "CirclePsfModel.h"

class RectanglePsfModel: public CirclePsfModel
{
public:

  /*** NOTE: units for both x/y directions are 0.05 arcseconds ***/

  /* Constructor */
   RectanglePsfModel(  double Energy,             /* Psf energy */
                    double Theta,              /* Off-axis angle */
                    double Phi,                /* Azimuthal angle */
                    vector<double> HalfWidth,  /* Box half-widths (asec) */
                    unsigned int NGridEls      /* 100 for 10*10 det map. */
                    );    

  /* Destructor */
  ~RectanglePsfModel();

  /* Calculate integrated PSF over a square area */
  double int_psf( double xboxcentre, 
		  double yboxcentre, 
		  double xboxsize,
		  double yboxsize) const;

  /* Calculate the PSF integrated within a rectangle */
  double rad_psf() const;

  string mode() const;

private:
  
  double _energy;
  double _theta;

  double _phi;
  vector<double> _radii;
  double _diagonal;
  unsigned int _ngridels;

  EncircledEnergyDataServer * _eds;

  EncircledEnergyFunction *eef;
};

#endif

